@@ -1,9 +1,14 @@
+from troposphere.secretsmanager import Secret
+
 from serverless.aws.resources.kms import EncryptableResource
 from serverless.service.plugins.generic import Generic
-from troposphere.secretsmanager import Secret
 
 
 class KMSSecrets(Generic):
+    """
+    Plugin npm: https://www.npmjs.com/package/serverless-secrets-mgr-plugin
+    """
+
     yaml_tag = "!AWSSecretsPlugin"
 
     def __init__(self, secrets):
